package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;

public class CertStatus extends ASN1Encodable {
   private ASN1OctetString certHash;
   private DERInteger certReqId;
   private PKIStatusInfo statusInfo;

   private CertStatus(ASN1Sequence seq) {
      this.certHash = ASN1OctetString.getInstance(seq.getObjectAt(0));
      this.certReqId = DERInteger.getInstance(seq.getObjectAt(1));
      if (seq.size() > 2) {
         this.statusInfo = PKIStatusInfo.getInstance(seq.getObjectAt(2));
      }

   }

   public static CertStatus getInstance(Object o) {
      if (o instanceof CertStatus) {
         return (CertStatus)o;
      } else if (o instanceof ASN1Sequence) {
         return new CertStatus((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   public DERInteger getCertReqId() {
      return this.certReqId;
   }

   public PKIStatusInfo getStatusInfo() {
      return this.statusInfo;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.certHash);
      var10001.add(this.certReqId);
      PKIStatusInfo var2;
      if ((var2 = this.statusInfo) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
